# -*- coding: utf-8 -*-
"""For full list, see: https://cdn.materialdesignicons.com/4.9.95/ ."""

import qtawesome as qta


def set_defaults(*args, **kwargs):
    qta.set_defaults(*args, **kwargs)
